@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.008003;
 
-our $VERSION = '1.647';
+our $VERSION = '1.648';
 
 use Exporter qw( import );
 
@@ -32,7 +32,6 @@ our @EXPORT_OK = qw(
 our %EXPORT_TAGS = (
     choose => [ qw(
         ROW COL
-        WIDTH_CURSOR
         MAX_ROW_MOUSE_1003 MAX_COL_MOUSE_1003
         NEXT_get_key
         CONTROL_SPACE CONTROL_A CONTROL_B CONTROL_C CONTROL_E CONTROL_F CONTROL_H KEY_BTAB CONTROL_I CONTROL_Q KEY_TAB
@@ -47,10 +46,10 @@ our %EXPORT_TAGS = (
     ) ],
     screen => [ qw(
         CLEAR_SCREEN CLEAR_TO_END_OF_SCREEN CLEAR_TO_END_OF_LINE UP DOWN RIGHT LEFT
-        RESET REVERSE UNDERLINE BOLD_UNDERLINE HIDE_CURSOR SHOW_CURSOR BEEP
+        RESET REVERSE UNDERLINE BOLD_UNDERLINE HIDE_CURSOR SHOW_CURSOR BEEP WIDTH_CURSOR
     ) ],
     linux  => [ qw(
-        GET_CURSOR_POSITION WIDTH_CURSOR
+        GET_CURSOR_POSITION
         SET_ANY_EVENT_MOUSE_1003 SET_EXT_MODE_MOUSE_1005 SET_SGR_EXT_MODE_MOUSE_1006
         UNSET_ANY_EVENT_MOUSE_1003 UNSET_EXT_MODE_MOUSE_1005 UNSET_SGR_EXT_MODE_MOUSE_1006
         NEXT_get_key
